const { Sequelize, DataTypes } = require('sequelize');
const Config = require('../config/config.js');

//importing models
const addon = require('./addon');
const addon_addon_item = require('./addon_addon_item');
const addon_item = require('./addon_item');
const addon_item_translation = require('./addon_item_translation');
const addon_translation = require('./addon_translation');
const brand = require('./brand');
const brand_translation = require('./brand_translation');
const menu_category = require('./menu_category');
const menu_category_translation = require('./menu_category_translation');
const menu_item = require('./menu_item');
const menu_item_addon = require('./menu_item_addon');
const menu_item_translation = require('./menu_item_translation');
const menu_item_variant = require('./menu_item_variant');
const menu_item_variant_translation = require('./menu_item_variant_translation');
const menu_variant = require('./menu_variant');
const menu_variant_addon = require('./menu_variant_addon');

const env = process.env.NODE_ENV || 'development';
const config = Config[env];
const db = {};

let sequelize;
if (config.use_env_variable) {
   sequelize = new Sequelize(process.env[config.use_env_variable], config);
} else {
   sequelize = new Sequelize(config.database, config.username, config.password, config);
}

// register models in db
db.addon = addon(sequelize, DataTypes);
db.addon_addon_item = addon_addon_item(sequelize, DataTypes);
db.addon_item = addon_item(sequelize, DataTypes);
db.addon_item_translation = addon_item_translation(sequelize, DataTypes);
db.addon_translation = addon_translation(sequelize, DataTypes);
db.brand = brand(sequelize, DataTypes);
db.brand_translation = brand_translation(sequelize, DataTypes);
db.menu_category = menu_category(sequelize, DataTypes);
db.menu_category_translation = menu_category_translation(sequelize, DataTypes);
db.menu_item = menu_item(sequelize, DataTypes);
db.menu_item_addon = menu_item_addon(sequelize, DataTypes);
db.menu_item_translation = menu_item_translation(sequelize, DataTypes);
db.menu_item_variant = menu_item_variant(sequelize, DataTypes);
db.menu_item_variant_translation = menu_item_variant_translation(sequelize, DataTypes);
db.menu_variant = menu_variant(sequelize, DataTypes);
db.menu_variant_addon = menu_variant_addon(sequelize, DataTypes);

Object.keys(db).forEach((modelName) => {
   if (db[modelName].associate) {
      db[modelName].associate(db);
   }
});

db.sequelize = sequelize;
db.Sequelize = Sequelize;

module.exports = db;