const { addonMessages } = require('../custom/constants');
const { addon, sequelize, addon_translation } = require('../models');
const { createAddonTranslation, updateAddonTranslation } = require('./addonTranslation.service')

const createAddon = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdAddon = await addon.create(payload.body);
      payload.body.addon_id = createdAddon.id;
      await createAddonTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(addonMessages.creationFailed);
  }
};

const deleteAddon = async (payload) => {
  try {
    const addonToDelete = await addon.findOne({ where: { id: payload.body.id } });
    if (addonToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;

      await sequelize.transaction(async () => {
        await addon.update(payload.body, { where: { id: payload.body.id } });
        await addonToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(addonMessages.noIdFound);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listAddon = async (payload) => {
  try {
    let addonDetails;
    const locale = payload.headers['locale'];
    addonDetails = await addon.findAll({
      include: [
        {
          model: addon_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (addonDetails) return addonDetails;
    throw new Error(addonMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getAddon = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const addons = await addon.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: addon_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (addons) return addons;
    throw new Error(addonMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateAddon = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;

    const addons = await addon.findOne({ where: { id: payload.body.id } });
    if (addons) {
    await sequelize.transaction(async () => {
      await addon.update(payload.body, { where: { id: payload.body.id } });
      await updateAddonTranslation(payload.body)
    });
    return true;
  };
  throw new Error(addonMessages.noIdFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const addonServices = {
  createAddon,
  deleteAddon,
  listAddon,
  getAddon,
  updateAddon
};

module.exports = addonServices;
