const { addonItemMessages } = require('../custom/constants');
const { addon_item, sequelize, addon_item_translation } = require('../models');
const { createAddonItemTranslation, updateAddonItemTranslation } = require('./addonItemTranslation.service');
const { updateBrandTranslation } = require('./brandTranslation.service');

const createAddonItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdAddonItem = await addon_item.create(payload.body);
      payload.body.addon_item_id = createdAddonItem.id;
      await createAddonItemTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(addonItemMessages.creationFailed);
  }
};

const deleteAddonItem = async (payload) => {
  try {
    const AddonItemToDelete = await addon_item.findOne({ where: { id: payload.body.id } });
    if (AddonItemToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;
      await sequelize.transaction(async () => {
        await addon_item.update(payload.body, { where: { id: payload.body.id } });
        await AddonItemToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(addonItemMessages.deleteFailed);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listAddonItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const AddonItemList = await addon_item.findAll({
      include: [
        {
          model: addon_item_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (AddonItemList) return AddonItemList;
    throw new Error(addonItemMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getAddonItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const AddonItem = await addon_item.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: addon_item_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (AddonItem) return AddonItem;
    throw new Error(addonItemMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateAddonItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    const addonItem = await addon_item.findOne({ where: { id: payload.body.id } })
    if (addonItem) {
      await sequelize.transaction(async () => {
        await addon_item.update(payload.body, { where: { id: payload.body.id } });
        await updateBrandTranslation(payload.body);
      });
      return true;
    };
    throw new Error(addonItemMessages.notFound)
  } catch (error) {
    throw new Error(error.message);
  }
}

const AddonItemServices = {
  createAddonItem,
  deleteAddonItem,
  listAddonItem,
  getAddonItem,
  updateAddonItem
};

module.exports = AddonItemServices;
