const { addonItemTranslationMessages } = require('../custom/constants');
const { addon_item_translation } = require('../models');

const createAddonItemTranslation = async (payload) => {
  try {
    const createdAddonItemTranslation = await addon_item_translation.create(payload);
    return createdAddonItemTranslation;
  } catch (error) {
    throw new Error(addonItemTranslationMessages.creationFailed);
  }
};

const deleteAddonItemTranslation = async (addonItemTransId) => {
  try {
    const addonItemTransToDelete = await addon_item_translation.findOne({ where: { id: addonItemTransId } });
    if (addonItemTransToDelete) {
      await addonItemTransToDelete.destroy();
      return true;
    } else {
      throw new Error(addonItemTranslationMessages.deleteFailed);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listAddonItemTranslation = async () => {
  try {
    const AddonItemTransList = await addon_item_translation.findAll();
    if (AddonItemTransList) return AddonItemTransList;
    throw new Error(addonItemTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getAddonItemTranslation = async (addonItemTransId) => {
  try {
    const AddonItemTrans = await addon_item_translation.findOne({ where: { id: addonItemTransId } });
    if (AddonItemTrans) return AddonItemTrans;
    throw new Error(addonItemTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateAddonItemTranslation = async (payload) => {
  try {
    const updatedAddonItemTrans = await addon_item_translation.update(payload, { where: { addon_item_id: payload.id, locale: payload.locale } });
    if (updatedAddonItemTrans) return true;
    throw new Error(addonItemTranslationMessages.updateFailed)
  } catch (error) {
    throw new Error(error.message);
  }
}

const AddonItemTranslationServices = {
  createAddonItemTranslation,
  deleteAddonItemTranslation,
  listAddonItemTranslation,
  getAddonItemTranslation,
  updateAddonItemTranslation
};

module.exports = AddonItemTranslationServices;
