const { addonTranslationMessages } = require('../custom/constants');
const { addon_translation } = require('../models');

const createAddonTranslation = async (payload) => {
  try {
    const createdAddonTrans = await addon_translation.create(payload);
    return createdAddonTrans;
  } catch (error) {
    throw new Error(addonTranslationMessages.creationFailed);
  }
};

const deleteAddonTranslation = async (addonTransId) => {
  try {
    const AddonTransToDelete = await addon_translation.findOne({ where: { id: addonTransId } });
    if (AddonTransToDelete) {
      await AddonTransToDelete.destroy();
      return true;
    } else {
      throw new Error(addonTranslationMessages.deleteFailed);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listAddonTranslation = async () => {
  try {
    const AddonTransList = await addon_translation.findAll();
    if (AddonTransList) return AddonTransList;
    throw new Error(addonTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getAddonTranslation = async (addonTransId) => {
  try {
    const AddonTrans = await addon_translation.findOne({ where: { id: addonTransId } });
    if (AddonTrans) return AddonTrans;
    throw new Error(addonTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateAddonTranslation = async (payload) => {
  try {
    const updatedAddonTrans = await addon_translation.update(payload, { where: { addon_id: payload.id, locale: payload.locale } });
    if (updatedAddonTrans) return true;
    throw new Error(addonTranslationMessages.updateFailed)
  } catch (error) {
    throw new Error(error.message);
  }
}

const AddonTranslationServices = {
  createAddonTranslation,
  deleteAddonTranslation,
  listAddonTranslation,
  getAddonTranslation,
  updateAddonTranslation
};

module.exports = AddonTranslationServices;
