const { brandMessages } = require('../custom/constants');
const { brand, sequelize, brand_translation } = require('../models');
const { createBrandTranslation, updateBrandTranslation } = require('./brandTranslation.service');

const createBrand = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.user_id = payload.user.id;
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdBrand = await brand.create(payload.body);
      payload.body.brand_id = createdBrand.id;
      await createBrandTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(brandMessages.creationFailed);
  }
};

const deleteBrand = async (payload) => {
  try {
    const brandToDelete = await brand.findOne({ where: { id: payload.body.id } });
    if (brandToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;
      await sequelize.transaction(async () => {
        await brand.update(payload.body, { where: { id: payload.body.id } });
        await brandToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(brandMessages.notFound);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listBrand = async (payload) => {
  try {
    let brandDetails;
    const locale = payload.headers['locale'];
    brandDetails = await brand.findAll({
      include: [
        {
          model: brand_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });

    if (brandDetails) return brandDetails;
    throw new Error(brandMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getBrand = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const brands = await brand.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: brand_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (brands) return brands;
    throw new Error(brandMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateBrand = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.user_id = payload.user.id;
    payload.body.locale = locale;
    const brandDetail = await brand.findOne({ where: { id: payload.body.id } })
    if (brandDetail) {
      await sequelize.transaction(async () => {
        await brand.update(payload.body, { where: { id: payload.body.id } });
        await updateBrandTranslation(payload.body);
      });
      return true;
    };
    throw new Error(brandMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const brandServices = {
  createBrand,
  deleteBrand,
  listBrand,
  getBrand,
  updateBrand
};

module.exports = brandServices;
