const { brandTranslationMessages } = require('../custom/constants');
const { brand_translation } = require('../models');

const createBrandTranslation = async (payload) => {
  try {
    const createdBrandTrans = await brand_translation.create(payload);
    return createdBrandTrans;
  } catch (error) {
    throw new Error(brandTranslationMessages.creationFailed);
  }
};

const deleteBrandTranslation = async (brandTransId) => {
  try {
    const brandTransToDelete = await brand_translation.findOne({ where: { id: brandTransId } });
    if (brandTransToDelete) {
      await brandTransToDelete.destroy();
      return true;
    } else {
      throw new Error(brandTranslationMessages.deleteFailed);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listBrandTranslation = async () => {
  try {
    const brandTransList = await brand_translation.findAll();
    if (brandTransList) return brandTransList;
    throw new Error(brandTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getBrandTranslation = async (brandTransId) => {
  try {
    const brandTrans = await brand_translation.findOne({ where: { id: brandTransId } });
    if (brandTrans) return brandTrans;
    throw new Error(brandTranslationMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateBrandTranslation = async (payload) => {
  try {
    const updatedBrandTrans = await brand_translation.update(payload, { where: { brand_id: payload.id, locale: payload.locale } });
    if (updatedBrandTrans) return true;
    throw new Error(brandTranslationMessages.updateFailed)
  } catch (error) {
    throw new Error(error.message);
  }
}

const brandTranslationServices = {
  createBrandTranslation,
  deleteBrandTranslation,
  listBrandTranslation,
  getBrandTranslation,
  updateBrandTranslation
};

module.exports = brandTranslationServices;
