const { menuCategotyMessages } = require('../custom/constants');
const { menu_category, sequelize, menu_category_translation } = require('../models');
const { createMenuCategoryTranslation, updateMenuCategoryTranslation } = require('./menuCategoryTranslation.service');

const createMenuCategory = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdMenuCategory = await menu_category.create(payload.body);
      payload.body.menu_category_id = createdMenuCategory.id;
      await createMenuCategoryTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(menuCategotyMessages.creationFailed);
  }
};

const deleteMenuCategory = async (payload) => {
  try {
    const menuCategotyToDelete = await menu_category.findOne({ where: { id: payload.body.id } });
    if (menuCategotyToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;
      await sequelize.transaction(async () => {
        await menu_category.update(payload.body, { where: { id: payload.body.id } });
        await menuCategotyToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(menuCategotyMessages.notFound);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listMenuCategory = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuCategories = await menu_category.findAll({
      include: [
        {
          model: menu_category_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuCategories) return menuCategories;
    throw new Error(menuCategotyMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getMenuCategory = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuCategory = await menu_category.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: menu_category_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuCategory) return menuCategory;
    throw new Error(menuCategotyMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateMenuCategory = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    const menuCategory = await menu_category.findOne({ where: { id: payload.body.id } });
    if (menuCategory) {
      await sequelize.transaction(async () => {
        await menu_category.update(payload.body, { where: { id: payload.body.id } });
        await updateMenuCategoryTranslation(payload.body);
      });
      return true;
    };
    throw new Error(menuCategotyMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const menuCategoryServices = {
  createMenuCategory,
  deleteMenuCategory,
  listMenuCategory,
  getMenuCategory,
  updateMenuCategory
};

module.exports = menuCategoryServices;
