const { menuItemMessages } = require('../custom/constants');
const { menu_item, sequelize, menu_item_translation } = require('../models');
const { createMenuItemTranslation, updateMenuItemTranslation } = require('./menuItemTranslation.service');

const createMenuItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdMenuItem = await menu_item.create(payload.body);
      payload.body.menu_item_id = createdMenuItem.id;
      await createMenuItemTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(menuItemMessages.creationFailed);
  }
};

const deleteMenuItem = async (payload) => {
  try {
    const menuItemToDelete = await menu_item.findOne({ where: { id: payload.body.id } });
    if (menuItemToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;
      await sequelize.transaction(async () => {
        await menu_item.update(payload.body, { where: { id: payload.body.id } });
        await menuItemToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(menuItemMessages.notFound);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listMenuItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuItemList = await menu_item.findAll({
      include: [
        {
          model: menu_item_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuItemList) return menuItemList;
    throw new Error(menuItemMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getMenuItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuItem = await menu_item.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: menu_item_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuItem) return menuItem;
    throw new Error(menuItemMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateMenuItem = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    const menuItem = menu_item.findOne({ where: { id: payload.body.id } });
    if (menuItem) {
      await sequelize.transaction(async () => {
        await menu_item.update(payload.body, { where: { id: payload.body.id } });
        await updateMenuItemTranslation(payload.body);
      });
      return true;
    };
    throw new Error(menuItemMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const menuItemServices = {
  createMenuItem,
  deleteMenuItem,
  listMenuItem,
  getMenuItem,
  updateMenuItem
};

module.exports = menuItemServices;
