const { menuItemTranslationMessages } = require('../custom/constants');
const { menu_item_translation } = require('../models');

const createMenuItemTranslation = async (payload) => {
    try {
        const createdMenuItemTranslation = await menu_item_translation.create(payload);
        return createdMenuItemTranslation;
    } catch (error) {
        throw new Error(menuItemTranslationMessages.creationFailed);
    }
};

const deleteMenuItemTranslation = async (menuItemTransId) => {
    try {
        const menuItemTransToDelete = await menu_item_translation.findOne({ where: { id: menuItemTransId } });
        if (menuItemTransToDelete) {
            await menuItemTransToDelete.destroy();
            return true;
        } else {
            throw new Error(menuItemTranslationMessages.deleteFailed);
        }
    } catch (error) {
        throw new Error(error.message);
    }
};

const listMenuItemTranslation = async () => {
    try {
        const menuItemTransList = await menu_item_translation.findAll();
        if (menuItemTransList) return menuItemTransList;
        throw new Error(menuItemTranslationMessages.notFound);
    } catch (error) {
        throw new Error(error.message);
    }
}

const getMenuItemTranslation = async (menuItemTransId) => {
    try {
        const menuItemTrans = await menu_item_translation.findOne({ where: { id: menuItemTransId } });
        if (menuItemTrans) return menuItemTrans;
        throw new Error(menuItemTranslationMessages.notFound);
    } catch (error) {
        throw new Error(error.message);
    }
}

const updateMenuItemTranslation = async (payload) => {
    try {
        const updatedMenuItemTrans = await menu_item_translation.update(payload, { where: { menu_item_id: payload.id, locale: payload.locale } });
        if (updatedMenuItemTrans) return true;
        throw new Error(menuItemTranslationMessages.updateFailed)
    } catch (error) {
        throw new Error(error.message);
    }
}

const menuItemTranslationServices = {
    createMenuItemTranslation,
    deleteMenuItemTranslation,
    listMenuItemTranslation,
    getMenuItemTranslation,
    updateMenuItemTranslation
};

module.exports = menuItemTranslationServices;
