const { menuItemVariantMessages } = require('../custom/constants');
const { menu_item_variant, sequelize, menu_item_variant_translation } = require('../models');
const { createMenuItemVariantTranslation, updateMenuItemVariantTranslation } = require('./menuItemVarientTranslation.service')

const createMenuItemVariant = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    payload.body.is_delete = false;
    await sequelize.transaction(async () => {
      const createdMenuItemVariant = await menu_item_variant.create(payload.body);
      payload.body.menu_item_variant_id = createdMenuItemVariant.id;
      await createMenuItemVariantTranslation(payload.body);
    });
    return true;
  } catch (error) {
    throw new Error(menuItemVariantMessages.creationFailed);
  }
};

const deleteMenuItemVariant = async (payload) => {
  try {
    const menuItemVariantToDelete = await menu_item_variant.findOne({ where: { id: payload.body.id } });
    if (menuItemVariantToDelete) {
      payload.body.deleted_by = payload.user.id;
      payload.body.is_delete = true;
      await sequelize.transaction(async () => {
        await menu_item_variant.update(payload.body, { where: { id: payload.body.id } });
        await menuItemVariantToDelete.destroy();
      });
      return true;
    } else {
      throw new Error(menuItemVariantMessages.deleteFailed);
    }
  } catch (error) {
    throw new Error(error.message);
  }
};

const listMenuItemVariant = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuItemVariantList = await menu_item_variant.findAll({
      include: [
        {
          model: menu_item_variant_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuItemVariantList) return menuItemVariantList;
    throw new Error(menuItemVariantMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const getMenuItemVariant = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    const menuItemVariant = await menu_item_variant.findOne({
      where: { id: payload.body.id },
      include: [
        {
          model: menu_item_variant_translation,
          where: { locale: locale },
          required: false
        }
      ]
    });
    if (menuItemVariant) return menuItemVariant;
    throw new Error(menuItemVariantMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const updateMenuItemVariant = async (payload) => {
  try {
    const locale = payload.headers['locale'];
    payload.body.locale = locale;
    const menuItemVariant = await menu_item_variant.findOne({ where: { id: payload.body.id } });
    if (menuItemVariant) {
      await sequelize.transaction(async () => {
        await menu_item_variant.update(payload.body, { where: { id: payload.body.id } });
        await updateMenuItemVariantTranslation(payload.body);
      });
      return true;
    };
    throw new Error(menuItemVariantMessages.notFound);
  } catch (error) {
    throw new Error(error.message);
  }
}

const menuItemVariantServices = {
  createMenuItemVariant,
  deleteMenuItemVariant,
  listMenuItemVariant,
  getMenuItemVariant,
  updateMenuItemVariant
};

module.exports = menuItemVariantServices;
