const { menuVariantMessages } = require('../custom/constants');
const { menu_variant } = require('../models');

const createMenuVariant = async (payload) => {
    try {
        const createdMenuVariant = await menu_variant.create(payload);
        return createdMenuVariant;
    } catch (error) {
        throw new Error(menuVariantMessages.creationFailed);
    }
};

const deleteMenuVariant = async (menuVariantId) => {
    try {
        const menuVariantToDelete = await menu_variant.findOne({ where: { id: menuVariantId } });
        if (menuVariantToDelete) {
            await menuVariantToDelete.destroy();
            return true;
        } else {
            throw new Error(menuVariantMessages.deleteFailed);
        }
    } catch (error) {
        throw new Error(error.message);
    }
};

const listMenuVariant = async () => {
    try {
        const menuVariantList = await menu_variant.findAll();
        if (menuVariantList) return menuVariantList;
        throw new Error(menuVariantMessages.notFound);
    } catch (error) {
        throw new Error(error.message);
    }
}

const getMenuVariant = async (menuVariantId) => {
    try {
        const menuVariant = await menu_variant.findOne({ where: { id: menuVariantId } });
        if (menuVariant) return menuVariant;
        throw new Error(menuVariantMessages.notFound);
    } catch (error) {
        throw new Error(error.message);
    }
}

const updateMenuVariant = async (payload, menuVariantId) => {
    try {
        const updatedMenuVariant = await menu_variant.update(payload, { where: { id: menuVariantId } });
        if (updatedMenuVariant) return true;
        throw new Error(menuVariantMessages.updateFailed)
    } catch (error) {
        throw new Error(error.message);
    }
}

const menuVariantServices = {
    createMenuVariant,
    deleteMenuVariant,
    listMenuVariant,
    getMenuVariant,
    updateMenuVariant
};

module.exports = menuVariantServices;
